.. python-alsa-midi documentation master file, created by
   sphinx-quickstart on Fri Dec 24 10:13:35 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to python-alsa-midi's documentation!
============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   README <overview>
   usage
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
